.. dargs documentation master file, created by
   sphinx-quickstart on Fri Apr 12 14:24:37 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to dargs's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   sphinx
   api/api
   credits


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
